Plots
=====

The :py:mod:`.plots` module contains plotting functions for Curveball.
Functions that plot growth data expect a :py:class:`pandas.DataFrame` generated by the :py:mod:`.ioutils` module.
Functions that plot the results of growth model fitting often expect the result of the fitting - one or more :py:class:`lmfit.model.ModelResult` objects.

Members
-------

.. automodule:: curveball.plots
   :members:
